pub(crate) async fn download_slice(
module_api: DynModuleApi,
peers: PeerPool,
start: u64,
end: u64,
expected_hash: Hash,
) -> Vec<RecoveryItem>Expand description
Download a slice, asking one guardian at a time and holding it for the duration of the request.