pub struct MintClientModule {
pub(crate) federation_id: FederationId,
pub(crate) cfg: MintClientConfig,
pub(crate) root_secret: DerivableSecret,
pub(crate) notifier: ModuleNotifier<MintClientStateMachines>,
pub(crate) client_ctx: ClientContext<Self>,
pub(crate) balance_update_sender: Sender<()>,
pub(crate) tweak_receiver: Receiver<[u8; 16]>,
}Fields
federation_id: FederationIdcfg: MintClientConfigroot_secret: DerivableSecretnotifier: ModuleNotifier<MintClientStateMachines>client_ctx: ClientContext<Self>balance_update_sender: Sender<()>tweak_receiver: Receiver<[u8; 16]>Implementations
Sourceimpl MintClientModule
impl MintClientModule
pub(crate) async fn select_funding_input( &self, dbtx: &mut DatabaseTransaction<'_>, excess_output: Amount, ) -> Option<Vec<SpendableNote>>
pub(crate) async fn rebalance( &self, dbtx: &mut DatabaseTransaction<'_>, fee: &FeeConsensus, excess_input: Amount, ) -> (Vec<SpendableNote>, Vec<Denomination>)
pub(crate) fn create_input_bundle( operation_id: OperationId, notes: Vec<SpendableNote>, include_receive_sm: bool, amount_unit: AmountUnit, ) -> ClientInputBundle<MintInput, MintClientStateMachines>
pub(crate) async fn create_output_bundle( &self, operation_id: OperationId, requested_denominations: Vec<Denomination>, ) -> ClientOutputBundle<MintOutput, MintClientStateMachines>
pub(crate) async fn await_output_sm_success( &self, operation_id: OperationId, outpoint: OutPoint, ) -> Result<()>
Sourcepub async fn get_count_by_denomination(&self) -> BTreeMap<Denomination, u64>
pub async fn get_count_by_denomination(&self) -> BTreeMap<Denomination, u64>
Count the ECash notes in the client’s database by denomination.
pub(crate) async fn get_count_by_denomination_dbtx( &self, dbtx: &mut DatabaseTransaction<'_>, ) -> BTreeMap<Denomination, u64>
Sourcepub async fn send(
&self,
amount: Amount,
custom_meta: Value,
include_invite: bool,
) -> Result<ECash, SendECashError>
pub async fn send( &self, amount: Amount, custom_meta: Value, include_invite: bool, ) -> Result<ECash, SendECashError>
Send ECash for the given amount. The
amount will be rounded up to a multiple of 512 msats which is the
smallest denomination used throughout the client. If the rounded
amount cannot be covered with the ecash notes in the client’s
database the client will create a transaction to reissue the
required denominations. It is safe to cancel the send method call
before the reissue is complete in which case the reissued notes are
returned to the regular balance. To cancel a successful ecash send
simply receive it yourself.
If include_invite is set, the federation’s invite code is embedded in
the returned ecash so a recipient that has not joined the federation can
do so directly from the received ecash.
pub(crate) async fn send_ecash_dbtx( &self, dbtx: &mut DatabaseTransaction<'_>, remaining_amount: Amount, custom_meta: Value, include_invite: bool, ) -> Result<Option<ECash>, Infallible>
Sourcepub async fn receive(
&self,
ecash: ECash,
custom_meta: Value,
) -> Result<OperationId, ReceiveECashError>
pub async fn receive( &self, ecash: ECash, custom_meta: Value, ) -> Result<OperationId, ReceiveECashError>
Receive the ECash by reissuing the notes and return the total amount
of the ecash reissued. This method is idempotent.
Sourcepub async fn await_final_receive_operation_state(
&self,
operation_id: OperationId,
) -> Result<FinalReceiveOperationState>
pub async fn await_final_receive_operation_state( &self, operation_id: OperationId, ) -> Result<FinalReceiveOperationState>
Await the final state of the receive operation.
pub(crate) async fn remove_spendable_note( &self, dbtx: &mut DatabaseTransaction<'_>, spendable_note: &SpendableNote, )